@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2011 Rocky Bernstein <rocky@cpan.org>
+# Copyright (C) 2011-2012 Rocky Bernstein <rocky@cpan.org>
 use warnings; no warnings 'redefine';
 use rlib '../../../..';
 
@@ -24,13 +24,16 @@ use vars qw(@ISA);
 use vars @CMD_VARS;
 
 $NAME = set_name();
-$HELP = <<"HELP";
+$HELP = <<'HELP';
+=pod 
+
 Generic command for showing things about the debugger.  You can
 give unique prefix of the name of a subcommand to get information
 about just that subcommand.
 
-Type ${NAME} for a list of ${NAME} subcommands and what they do.
-Type "help ${NAME} *" for just a list of ${NAME} subcommands.
+Type C<show> for a list of show subcommands and what they do.
+Type C<help show *> for a list of C<show> subcommands.
+=cut
 HELP
 
 sub run($$) 
@@ -38,15 +41,15 @@ sub run($$)
     my ($self, $args) = @_;
     my $first;
     if (scalar @$args > 1) {
-	$first = lc $args->[1];
-	my $alen = length('auto');
-	splice(@$args, 1, 2, ('auto', substr($first, $alen))) if
-	    index($first, 'auto') == 0 && length($first) > $alen;
+        $first = lc $args->[1];
+        my $alen = length('auto');
+        splice(@$args, 1, 2, ('auto', substr($first, $alen))) if
+            index($first, 'auto') == 0 && length($first) > $alen;
     }
     $self->SUPER::run($args);
 }
 
-if (__FILE__ eq  $0) {
+unless (caller) {
     require Devel::Trepan::CmdProcessor;
     my $proc = Devel::Trepan::CmdProcessor->new(undef, 'bogus');
     my $cmd = __PACKAGE__->new($proc, $NAME);
